# Ensembl Python Base Library

Centralise generic Python code use across all other project within Ensembl, more particularly database access layers and ORMs, reusable eHive components, etc.

## Contents
Check out [installation](install.md) section for further information on how to install the project.

1. [Install](install.md)
2. [Code of Conduct](code_of_conduct.md)
3. [Coverage report](coverage.md)
4. [Code reference](reference/)

## License
Software as part of [Ensembl Python Base Library](https://github.com/Ensembl/ensembl-py) is distributed under the [Apache-2.0 License](https://www.apache.org/licenses/LICENSE-2.0.txt).
